@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: conduit-combinators
 version: 1.0.3.1
-id: conduit-combinators-1.0.3.1-dee0b8ffe69f92493a3f0964656aeb3e
-key: condu_3KmvgdgKXtN1cwBWWKMYOO
+id: conduit-combinators-1.0.3.1-4df458d222c24e4d94af85e4b0c56c7e
+key: condu_CNm6DZXsV5O4ingT20oTp9
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/fpco/conduit-combinators
@@ -21,19 +21,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
-hs-libraries: HSconduit-combinators-1.0.3.1-3KmvgdgKXtN1cwBWWKMYOO
+hs-libraries: HSconduit-combinators-1.0.3.1-CNm6DZXsV5O4ingT20oTp9
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
     base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    chunked-data-0.2.0-7f3077a014828f2c9ef957d0fe9eb847
+    chunked-data-0.2.0-4e0b1e7ec0ddce94d0cbc9c24739d039
     conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
-    conduit-extra-1.1.10-5c65857e3dfbc5cf563dbabcd22bcb07
+    conduit-extra-1.1.10.1-e4383b2e14cc80179dd5007ca51887df
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    mono-traversable-0.10.1.1-f79bc7831a1f09825852f2c78d51d1f8
-    mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
+    mono-traversable-0.10.1.1-444d89c530a7a69af62384c66ba2d700
+    mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
     text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
